@@ -7,14 +7,16 @@ class Site(BaseEntity):
     base_url = None
     author = None
     name = None
+    description = None
     analytics = None
     cover_photo = None
     twitter = None
     facebook = None
     googleplus = None
     linkedin = None
-    atom_url = None
+    rss_url = None
     avatar = None
+    timezone = 'Europe/Zurich'
 
     def __init__(self, **kwargs):
         for k in kwargs.keys():
